@@ -5,11 +5,11 @@
 ### incompleteBesselKR also requires a number of additional R functions:
 ###     SSFcoef, combinatorial, GDENOM, and GNUM
 
-incompleteBesselK <- function(x, y, nu, tol = (.Machine$double.eps)^(0.85),
-                              nmax = 120) {
-
+incompleteBesselK <- function(x, y, nu, tol = .Machine$double.eps^0.85,
+                              nmax = 120)
+{
   KNu <- besselK(2*sqrt(x*y), nu)
-  IBFOut <- .Fortran("incompleteBesselK",
+  IBFOut <- .Fortran(C_incompletebesselk, # ../src/IncompleteBessel.f
                      as.double(x),
                      as.double(y),
                      as.double(nu),
@@ -17,21 +17,19 @@ incompleteBesselK <- function(x, y, nu, tol = (.Machine$double.eps)^(0.85),
                      as.integer(nmax),
                      as.double(KNu),
                      IBF = double(1),
-                     status = integer(1)
-                     )
+                     status = integer(1))
   ## for debugging
   ##str(IBFOut)
   status <- IBFOut$status
-  IBF <- IBFOut$IBF
   if(status == 1) warning("Maximum order exceeded\nResult may be unreliable")
-  return(IBF)
+  ## return
+  IBFOut$IBF
 }
 
 
-
-incompleteBesselKR <- function(x, y, nu,
-                               tol = (.Machine$double.eps)^(0.85),
-                               nmax = 120) {
+incompleteBesselKR <- function(x, y, nu, tol = .Machine$double.eps^0.85,
+                               nmax = 120)
+{
   Am <- matrix(rep(0, (nmax + 1)^2), ncol = nmax + 1)
   An <- matrix(rep(0, (nmax + 1)^2), ncol = nmax + 1)
   Cnp <- numeric((nmax + 1)*(nmax + 2)/2)
